whisk package
=============

Submodules
----------

whisk.cli module
----------------

.. automodule:: whisk.cli
    :members:
    :undoc-members:
    :show-inheritance:

whisk.whisk module
------------------

.. automodule:: whisk.whisk
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: whisk
    :members:
    :undoc-members:
    :show-inheritance:
